@@ -9,24 +9,23 @@
 #' data(agaricus.test, package='xgboost')
 #' train <- agaricus.train
 #' test <- agaricus.test
-#' bst <- xgboost(data = train$data, label = train$label, max.depth = 2, 
-#'                eta = 1, nthread = 2, nround = 2,objective = "binary:logistic")
+#' bst <- xgboost(data = train$data, label = train$label, max_depth = 2, 
+#'                eta = 1, nthread = 2, nrounds = 2,objective = "binary:logistic")
 #' xgb.save(bst, 'xgb.model')
 #' bst <- xgb.load('xgb.model')
 #' pred <- predict(bst, test$data)
 #' @export
-#' 
 xgb.load <- function(modelfile) {
-  if (is.null(modelfile)) 
+  if (is.null(modelfile))
     stop("xgb.load: modelfile cannot be NULL")
-  
+
   handle <- xgb.Booster(modelfile = modelfile)
-  # re-use modelfile if it is raw so we donot need to serialize
+  # re-use modelfile if it is raw so we do not need to serialize
   if (typeof(modelfile) == "raw") {
     bst <- xgb.handleToBooster(handle, modelfile)
   } else {
     bst <- xgb.handleToBooster(handle, NULL)
   }
-  bst <- xgb.Booster.check(bst)
+  bst <- xgb.Booster.check(bst, saveraw = TRUE)
   return(bst)
-} 
+}
